Unit Testing
::::::::::::

.. toctree::
   :maxdepth: 2

   intro-UnitTesting.rst
   CheckingAssumptionsWithAssert.rst
   TestingFunctions.rst
   DesigningTestableFunctions.rst
   WritingUnitTests.rst
   TestFirstDevelopment.rst
   TestingWithpytest.rst
   Glossary.rst
   Exercises.rst
   